@@ -1,17 +1,16 @@
 use strict;
 package Event::timer;
 use Carp;
-use Time::HiRes qw(time);
 
-'Event'->register;
+'Event::Watcher'->register;
 
 sub new {
 #    lock %Event::;
 
-    shift;
+    shift if @_ & 1;
     my %arg = @_;
     my $o = allocate();
-    Event::init($o, [qw(hard)], \%arg);
+    $o->init([qw(hard)], \%arg);
 
     for (qw(after at interval)) {
 	$arg{$_} = $arg{"-$_"} if exists $arg{"-$_"};
@@ -20,7 +19,7 @@ sub new {
     if (exists $arg{after}) {
 	croak "'after' and 'at' are mutually exclusive"
 	    if exists $arg{at};
-	$o->{at} = time() + $arg{after};
+	$o->{at} = Event::time() + $arg{after};
 	$o->{interval} = $arg{after} if !exists $arg{interval};
     }
     elsif (exists $arg{at}) {
@@ -29,7 +28,7 @@ sub new {
 
     if (exists $arg{interval}) {
 	my $i = $arg{interval};
-	$o->{at} = time() + (ref $i? $$i : $i) unless $arg{at};
+	$o->{at} = Event::time() + (ref $i? $$i : $i) unless $arg{at};
 	$o->{interval} = $i;
 	$o->{repeat} = 1;
     }
